@@ -23,14 +23,14 @@ describe('ncp broken symlink', () => {
 
   afterEach(done => fse.remove(TEST_DIR, done))
 
-  it('should error if symlink is broken', done => {
+  it('should not error if symlink is broken', done => {
     ncp(src, out, err => {
-      assert(err)
+      assert.strictEqual(err, null)
       done()
     })
   })
 
-  it('should return an error when dereference=true', done => {
+  it('should return an error if symlink is broken and dereference=true', done => {
     ncp(src, out, { dereference: true }, err => {
       assert.strictEqual(err.code, 'ENOENT')
       done()
