@@ -24,15 +24,15 @@ describe('+ emptyDir()', () => {
   describe('> when directory exists and contains items', () => {
     it('should delete all of the items', done => {
       // verify nothing
-      assert.equal(fs.readdirSync(TEST_DIR).length, 0)
+      assert.strictEqual(fs.readdirSync(TEST_DIR).length, 0)
       fse.ensureFileSync(path.join(TEST_DIR, 'some-file'))
       fse.ensureFileSync(path.join(TEST_DIR, 'some-file-2'))
       fse.ensureDirSync(path.join(TEST_DIR, 'some-dir'))
-      assert.equal(fs.readdirSync(TEST_DIR).length, 3)
+      assert.strictEqual(fs.readdirSync(TEST_DIR).length, 3)
 
       fse.emptyDir(TEST_DIR, err => {
         assert.ifError(err)
-        assert.equal(fs.readdirSync(TEST_DIR).length, 0)
+        assert.strictEqual(fs.readdirSync(TEST_DIR).length, 0)
         done()
       })
     })
@@ -40,10 +40,10 @@ describe('+ emptyDir()', () => {
 
   describe('> when directory exists and contains no items', () => {
     it('should do nothing', done => {
-      assert.equal(fs.readdirSync(TEST_DIR).length, 0)
+      assert.strictEqual(fs.readdirSync(TEST_DIR).length, 0)
       fse.emptyDir(TEST_DIR, err => {
         assert.ifError(err)
-        assert.equal(fs.readdirSync(TEST_DIR).length, 0)
+        assert.strictEqual(fs.readdirSync(TEST_DIR).length, 0)
         done()
       })
     })
@@ -55,7 +55,7 @@ describe('+ emptyDir()', () => {
       assert(!fs.existsSync(TEST_DIR))
       fse.emptyDir(TEST_DIR, err => {
         assert.ifError(err)
-        assert.equal(fs.readdirSync(TEST_DIR).length, 0)
+        assert.strictEqual(fs.readdirSync(TEST_DIR).length, 0)
         done()
       })
     })
