@@ -26,9 +26,7 @@ describe('native fs', () => {
   })
 
   it('should have native fs constants', () => {
-    // Node.js v0.12 / IO.js
-    if ('F_OK' in fs) {
-      assert.strictEqual(fse.F_OK, fs.F_OK)
-    }
+    assert.strictEqual(fse.constants.F_OK, fs.constants.F_OK)
+    assert.strictEqual(fse.F_OK, fs.F_OK) // soft deprecated usage, but still available
   })
 })
