@@ -30,8 +30,7 @@ describe('mkdirp: issue-209, win32, when bad path, should return a cleaner error
       try {
         const file = 'c:\\tmp\foo:moo'
         fse.mkdirpSync(file)
-      } catch (err) {
-        // console.error(err)
+      } catch {
         didErr = true
       }
       assert(didErr)
