@@ -7,20 +7,18 @@ const assert = require('assert')
 
 /* global describe, it */
 
-const o755 = parseInt('755', 8)
-
 describe('mkdirp / root', () => {
-  // '/' on unix, 'c:/' on windows.
+  // '/' on unix
   const dir = path.normalize(path.resolve(path.sep)).toLowerCase()
 
-  // if not 'c:\\' or 'd:\\', it's probably a network mounted drive, this fails then. TODO: investigate
-  if (process.platform === 'win32' && (dir.indexOf('c:\\') === -1) && (dir.indexOf('d:\\') === -1)) return
+  // Windows does not have permission to mkdir on root
+  if (process.platform === 'win32') return
 
   it('should', done => {
-    fse.mkdirp(dir, o755, err => {
-      if (err) throw err
+    fse.mkdirp(dir, 0o755, err => {
+      if (err) return done(err)
       fs.stat(dir, (er, stat) => {
-        if (er) throw er
+        if (er) return done(er)
         assert.ok(stat.isDirectory(), 'target is a directory')
         done()
       })
