@@ -140,6 +140,17 @@ describe('+ move()', () => {
       })
     })
 
+    it('should support promises', async () => {
+      const src = path.join(TEST_DIR, 'a-file')
+      const dest = path.join(TEST_DIR, 'a-file-dest')
+
+      await fse.move(src, dest)
+
+      const contents = fs.readFileSync(dest, 'utf8')
+      const expected = /^sonic the hedgehog\r?\n$/
+      assert.ok(contents.match(expected))
+    })
+
     it('should not move a file if source and destination are the same', done => {
       const src = path.join(TEST_DIR, 'a-file')
       const dest = src
@@ -273,6 +284,34 @@ describe('+ move()', () => {
     })
   })
 
+  describe('> when opts is explicit undefined', () => {
+    it('works with callbacks', done => {
+      const src = path.join(TEST_DIR, 'a-file')
+      const dest = path.join(TEST_DIR, 'a-file-dest')
+
+      fse.move(src, dest, undefined, err => {
+        assert.ifError(err)
+        fs.readFile(dest, 'utf8', (err, contents) => {
+          const expected = /^sonic the hedgehog\r?\n$/
+          assert.ifError(err)
+          assert.ok(contents.match(expected))
+          done()
+        })
+      })
+    })
+
+    it('works with promises', async () => {
+      const src = path.join(TEST_DIR, 'a-file')
+      const dest = path.join(TEST_DIR, 'a-file-dest')
+
+      await fse.move(src, dest, undefined)
+
+      const contents = fs.readFileSync(dest, 'utf8')
+      const expected = /^sonic the hedgehog\r?\n$/
+      assert.ok(contents.match(expected))
+    })
+  })
+
   describeIfWindows('> when dest parent is root', () => {
     let dest
 
