@@ -4,11 +4,8 @@ const fs = require(process.cwd())
 const os = require('os')
 const path = require('path')
 const assert = require('assert')
-const atLeastNode = require('at-least-node')
 const stat = require('../stat.js')
 
-const NODE_VERSION_WITH_BIGINT = '10.5.0'
-
 /* global beforeEach, afterEach, describe, it */
 
 describe('util/stat', () => {
@@ -21,20 +18,15 @@ describe('util/stat', () => {
 
   afterEach(done => fs.remove(TEST_DIR, done))
 
-  describe('should use stats with bigint type for node versions >= 10.5.0 and number type for older versions', () => {
+  describe('should use stats with bigint type', () => {
     it('stat.checkPaths()', () => {
       const src = path.join(TEST_DIR, 'src')
       const dest = path.join(TEST_DIR, 'dest')
       fs.ensureFileSync(src)
       fs.ensureFileSync(dest)
-      stat.checkPaths(src, dest, 'copy', (err, stats) => {
+      stat.checkPaths(src, dest, 'copy', {}, (err, stats) => {
         assert.ifError(err)
-        const { srcStat } = stats
-        if (atLeastNode(NODE_VERSION_WITH_BIGINT)) {
-          assert.strictEqual(typeof srcStat.ino, 'bigint')
-        } else {
-          assert.strictEqual(typeof srcStat.ino, 'number')
-        }
+        assert.strictEqual(typeof stats.srcStat.ino, 'bigint')
       })
     })
 
@@ -43,12 +35,8 @@ describe('util/stat', () => {
       const dest = path.join(TEST_DIR, 'dest')
       fs.ensureFileSync(src)
       fs.ensureFileSync(dest)
-      const { srcStat } = stat.checkPathsSync(src, dest, 'copy')
-      if (atLeastNode(NODE_VERSION_WITH_BIGINT)) {
-        assert.strictEqual(typeof srcStat.ino, 'bigint')
-      } else {
-        assert.strictEqual(typeof srcStat.ino, 'number')
-      }
+      const { srcStat } = stat.checkPathsSync(src, dest, 'copy', {})
+      assert.strictEqual(typeof srcStat.ino, 'bigint')
     })
   })
 
